@@ -25,11 +25,11 @@ Marketplace::Ebay - Making API calls to eBay (with XSD validation)
 
 =head1 VERSION
 
-Version 0.19
+Version 0.191
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.191';
 
 =head1 SYNOPSIS
 
@@ -231,11 +231,16 @@ sub api_call {
     $self->_set_last_parsed_response(undef);
     if ($response->is_success) {
         my $struct;
+        my $xml = $response->decoded_content;
+        if ($call eq 'GetOrders') {
+            # until they don't publish an updated xsd
+            $xml =~ s!<GuaranteedShipping>(false|true)</GuaranteedShipping>!!g;
+        }
         if ($options->{no_validate}) {
-            $struct = XMLin($response->decoded_content);
+            $struct = XMLin($xml);
         }
         else {
-            $struct = $self->_parse_response($call, $response->decoded_content)
+            $struct = $self->_parse_response($call, $xml);
         }
         if ($struct) {
             my $obj = Marketplace::Ebay::Response->new(struct => $struct);
